Learn R Programming

bespatial (version 0.1.3)

bes_g_cushman: Configurational entropy for surfaces

Description

Calculates Cushman's configurational entropy for surfaces (2021)

Usage

bes_g_cushman(x, nr_of_permutations = 1000, independent = FALSE)

Value

A tibble

Arguments

x

SpatRaster, stars, RasterLayer, RasterStack, RasterBrick, matrix, or array containing one or more continuous rasters

nr_of_permutations

Number of permutations performed on each input raster to calculate possible distribution of "slope" values

independent

Should an independent set of permutations be performed for each input raster? TRUE/FALSE. Use FALSE (default) when each of your input rasters has the same configuration.

References

Cushman, S. A. (2021). Generalizing Boltzmann Configurational Entropy to Surfaces, Point Patterns and Landscape Mosaics. In Entropy (Vol. 23, Issue 12, p. 1616). MDPI AG. https://doi.org/10.3390/e23121616

Examples

Run this code
# \donttest{
  library(bespatial)
  library(terra)
  gradient = rast(system.file("raster/gradient.tif", package = "bespatial"),
                       lyrs = 1)
  ce2 = bes_g_cushman(gradient, 100)
  plot(gradient, main = round(ce2$value, 2))
  bes_g_cushman(gradient, 1000, independent = TRUE)
# }

Run the code above in your browser using DataLab