Learn R Programming

bespatial (version 0.1.3)

get_total_edge: Calculate total edge based on the input matrix

Description

Calculate total edge based on the input matrix

Usage

get_total_edge(x, resolution, neighbourhood = as.matrix(4))

Value

A total edge value

Arguments

x

A matrix

resolution

A numeric vector with two values representing the input matrix resolution on the x and y axis

neighbourhood

The number of directions in which cell adjacencies are considered as neighbours: 4 (rook's case), 8 (queen's case) or a binary matrix where the ones define the neighbourhood. The default is 4.